@@ -1,21 +1,22 @@
+from covid_shared.cli_tools.cleanup import finish_application
 from covid_shared.cli_tools.decorators import (
-    add_verbose,
-    add_with_debugger,
-    add_verbose_and_with_debugger,
-    pass_run_metadata,
-    with_output_root,
-    with_mark_best,
-    with_production_tag,
-    add_output_options,
-    add_r_singularity_option,
     add_mobility_gpr_dependency_option,
     add_model_inputs_dependency_option,
+    add_output_options,
+    add_r_singularity_option,
     add_seir_covariates_dependency_option,
     add_snapshot_dependency_option,
+    add_verbose,
+    add_verbose_and_with_debugger,
+    add_with_debugger,
+    pass_run_metadata,
+    with_mark_best,
+    with_output_root,
+    with_production_tag,
 )
 from covid_shared.cli_tools.logging import (
-    LOG_FORMATS,
     DEFAULT_LOG_MESSAGING_FORMAT,
+    LOG_FORMATS,
     add_logging_sink,
     configure_logging_to_files,
     configure_logging_to_terminal,
@@ -25,13 +26,13 @@ from covid_shared.cli_tools.metadata import (
     RunMetadata,
     YamlIOMixin,
     get_function_full_argument_mapping,
-    monitor_application,
     handle_exceptions,
+    monitor_application,
     update_with_previous_metadata,
 )
 from covid_shared.cli_tools.run_directory import (
-    get_last_stage_directory,
     get_current_previous_version,
+    get_last_stage_directory,
     get_run_directory,
     make_links,
     make_run_directory,
@@ -45,9 +46,4 @@ from covid_shared.cli_tools.run_directory import (
     move_link,
     setup_directory_structure,
 )
-from covid_shared.cli_tools.cleanup import (
-    finish_application,
-)
-from covid_shared.cli_tools.validation import (
-    validate_options_with_q,
-)
+from covid_shared.cli_tools.validation import validate_best_and_production_tags
