@@ -1,18 +1,18 @@
-from bdb import BdbQuit
 import datetime
 import functools
-from pathlib import Path
-from pprint import pformat
 import sys
 import time
 import traceback
 import types
 import typing
+from bdb import BdbQuit
+from pathlib import Path
+from pprint import pformat
 from typing import Any, Callable, Dict, Mapping, Optional, Union
 
 import click
-from loguru import logger
 import yaml
+from loguru import logger
 
 from covid_shared import paths
 
@@ -51,7 +51,9 @@ class Metadata:
 
     def update_from_file(self, metadata_key: str, metadata_file: typing.TextIO):
         """Loads a metadata file from disk and stores it in the key."""
-        logger.warning('Base metadata information cannot be constructed from a file. Returning empty metadata.')
+        logger.warning(
+            "Base metadata information cannot be constructed from a file. Returning empty metadata."
+        )
 
     def to_dict(self):
         """Give back a dict version of the metadata."""
@@ -64,7 +66,7 @@ class Metadata:
         if metadata_key in self:
             # This feels like a weird use of KeyError.  AttributeError also
             # feels wrong.  Maybe write a custom error later.
-            raise KeyError(f'Metadata key {metadata_key} has already been set.')
+            raise KeyError(f"Metadata key {metadata_key} has already been set.")
         self._metadata[metadata_key] = value
 
     def __contains__(self, metadata_key: str):
@@ -72,7 +74,9 @@ class Metadata:
 
     def dump(self, metadata_file: typing.TextIO):
         """Interface to dump metadata to disk."""
-        logger.warning('Base metadata class should not be used to dump information to a file.')
+        logger.warning(
+            "Base metadata class should not be used to dump information to a file."
+        )
         pass
 
     def __repr__(self):
@@ -89,13 +93,13 @@ class RunMetadata(Metadata, YamlIOMixin):
     def __init__(self, *args, **kwargs):
         self._start = time.time()
         super().__init__(*args, **kwargs)
-        self['start_time'] = datetime.datetime.now().strftime("%Y_%m_%d_%H_%M_%S")
+        self["start_time"] = datetime.datetime.now().strftime("%Y_%m_%d_%H_%M_%S")
 
     def update_from_path(self, metadata_key: str, metadata_path: Union[str, Path]):
         """Updates metadata from a metadata file path."""
         metadata_path = Path(metadata_path)
         if not metadata_path.name == paths.METADATA_FILE_NAME.name:
-            raise ValueError('Can only update from `metadata.yaml` files.')
+            raise ValueError("Can only update from `metadata.yaml` files.")
         with metadata_path.open() as metadata_file:
             self.update_from_file(metadata_key, metadata_file)
 
@@ -104,17 +108,23 @@ class RunMetadata(Metadata, YamlIOMixin):
         self._metadata[metadata_key] = yaml.full_load(metadata_file)
 
     def dump(self, metadata_file_path: Union[str, Path]):
-        self._metadata['run_time'] = f"{time.time() - self._start:.2f} seconds"
+        self._metadata["run_time"] = f"{time.time() - self._start:.2f} seconds"
         try:
-            with Path(metadata_file_path).open('w') as metadata_file:
+            with Path(metadata_file_path).open("w") as metadata_file:
                 self._write(self._metadata, metadata_file)
         except FileNotFoundError:
-            logger.warning(f'Output directory for {metadata_file.name} does not exist. Dumping metadata to console.')
+            logger.warning(
+                f"Output directory for {metadata_file.name} does not exist. Dumping metadata to console."
+            )
             click.echo(pformat(self._metadata))
 
 
-def monitor_application(func: types.FunctionType, logger_: Any, with_debugger: bool,
-                        app_metadata: Optional[Metadata] = None) -> Callable:
+def monitor_application(
+    func: types.FunctionType,
+    logger_: Any,
+    with_debugger: bool,
+    app_metadata: Optional[Metadata] = None,
+) -> Callable:
     """Monitors an application for errors and injects a metadata container.
 
     Catches records them if they occur. Can also be configured to drop
@@ -135,35 +145,39 @@ def monitor_application(func: types.FunctionType, logger_: Any, with_debugger: b
     """
     if app_metadata is None:
         app_metadata = Metadata()
+
     @functools.wraps(func)
     def _wrapped(*args, **kwargs):
         result = None
         try:
             # Record arguments for the run and inject the metadata
-            app_metadata['main_function'] = f'{func.__module__}:{func.__name__}'
-            app_metadata['run_arguments'] = get_function_full_argument_mapping(func, app_metadata,
-                                                                               *args, **kwargs)
+            app_metadata["main_function"] = f"{func.__module__}:{func.__name__}"
+            app_metadata["run_arguments"] = get_function_full_argument_mapping(
+                func, app_metadata, *args, **kwargs
+            )
             result = func(app_metadata, *args, **kwargs)
-            app_metadata['success'] = True
+            app_metadata["success"] = True
         except (BdbQuit, KeyboardInterrupt):
-            app_metadata['success'] = False
-            app_metadata['error_info'] = 'User interrupt.'
+            app_metadata["success"] = False
+            app_metadata["error_info"] = "User interrupt."
         except Exception as e:
             # For general errors, write exception info to the metadata.
-            app_metadata['success'] = False
+            app_metadata["success"] = False
             logger_.exception("Uncaught exception {}".format(e))
             exc_type, exc_value, exc_traceback = sys.exc_info()
-            app_metadata['error_info'] = {
-                'exception_type': exc_type,
-                'exception_value': exc_value,
-                'exc_traceback': traceback.format_tb(exc_traceback)
+            app_metadata["error_info"] = {
+                "exception_type": exc_type,
+                "exception_value": exc_value,
+                "exc_traceback": traceback.format_tb(exc_traceback),
             }
             if with_debugger:
                 import pdb
+
                 traceback.print_exc()
                 pdb.post_mortem()
         finally:
             return app_metadata, result
+
     return _wrapped
 
 
@@ -181,6 +195,7 @@ def handle_exceptions(func: Callable, logger_: Any, with_debugger: bool) -> Call
             if with_debugger:
                 import pdb
                 import traceback
+
                 traceback.print_exc()
                 pdb.post_mortem()
             else:
@@ -191,7 +206,7 @@ def handle_exceptions(func: Callable, logger_: Any, with_debugger: bool) -> Call
 
 def update_with_previous_metadata(run_metadata: RunMetadata, input_root: Path) -> RunMetadata:
     """Convenience function for updating metadata from an input source."""
-    key = str(input_root.resolve()).replace(' ', '_').replace('-', '_').lower() + '_metadata'
+    key = str(input_root.resolve()).replace(" ", "_").replace("-", "_").lower() + "_metadata"
     with (input_root / paths.METADATA_FILE_NAME).open() as input_metadata_file:
         run_metadata.update_from_file(key, input_metadata_file)
     return run_metadata
