@@ -17,6 +17,7 @@ def _lazy_import_callable(module_path: str, object_name: str):
         module = importlib.import_module(module_path)
         return getattr(module, object_name)
     except ModuleNotFoundError:
+
         def f(*args, **kwargs):
             raise ModuleNotFoundError(
                 f"No module named '{module_path}' and so we cannot find '{object_name}'. "
@@ -24,21 +25,24 @@ def _lazy_import_callable(module_path: str, object_name: str):
                 f"[global]\n"
                 f"extra-index-url = https://artifactory.ihme.washington.edu/artifactory/api/pypi/pypi-shared/simple\n"
                 f"trusted-host = artifactory.ihme.washington.edu/artifactory/api/pypi/pypi-shared\n\n"
-                f"and run 'pip install {module_path.split('.')[0]}'")
+                f"and run 'pip install {module_path.split('.')[0]}'"
+            )
+
         return f
 
 
 try:
     from db_queries.api.internal import get_location_hierarchy_by_version
 except ModuleNotFoundError:
-    get_location_hierarchy_by_version = _lazy_import_callable('db_queries.api.internal',
-                                                              'get_location_hierarchy_by_version')
+    get_location_hierarchy_by_version = _lazy_import_callable(
+        "db_queries.api.internal", "get_location_hierarchy_by_version"
+    )
 
 
-def load_location_hierarchy(location_set_version_id: int = None,
-                            location_file: Path = None):
-    assert ((location_set_version_id and not location_file)
-            or (not location_set_version_id and location_file))
+def load_location_hierarchy(location_set_version_id: int = None, location_file: Path = None):
+    assert (location_set_version_id and not location_file) or (
+        not location_set_version_id and location_file
+    )
 
     if location_set_version_id:
         return get_location_hierarchy_by_version(
@@ -47,6 +51,7 @@ def load_location_hierarchy(location_set_version_id: int = None,
     else:
         return pd.read_csv(location_file)
 
+
 ##############
 # GROSS HACK #
 ##############
@@ -55,7 +60,7 @@ def load_location_hierarchy(location_set_version_id: int = None,
 # to stdout. Before we import structlog (via jobmon_uge via jobmon),
 # put the name in the system's list of imported modules as an alias
 # to the python std library logging module.
-sys.modules['structlog'] = sys.modules['logging']
+sys.modules["structlog"] = sys.modules["logging"]
 
 try:
     from jobmon.client.api import Tool
@@ -63,7 +68,9 @@ try:
     from jobmon.client.workflow import WorkflowRunStatus
     from jobmon.exceptions import WorkflowAlreadyComplete
 except ModuleNotFoundError:
-    Tool = _lazy_import_callable('jobmon.client.api', 'Tool')
-    Task = _lazy_import_callable('jobmon.client.task', 'Task')
-    WorkflowRunStatus = _lazy_import_callable('jobmon.client.workflow', 'WorkflowRunStatus')
-    WorkflowAlreadyComplete = _lazy_import_callable('jobmon.exceptions', 'WorkflowAlreadyComplete')
+    Tool = _lazy_import_callable("jobmon.client.api", "Tool")
+    Task = _lazy_import_callable("jobmon.client.task", "Task")
+    WorkflowRunStatus = _lazy_import_callable("jobmon.client.workflow", "WorkflowRunStatus")
+    WorkflowAlreadyComplete = _lazy_import_callable(
+        "jobmon.exceptions", "WorkflowAlreadyComplete"
+    )
