@@ -27,12 +27,15 @@ RCLONE_CONFIG_PATH = COVID_19 / ".config" / "rclone" / "rclone.conf"
 # TODO: This should definitely be in a container.
 AGE_SPECIFIC_RATES_ROOT = COVID_19 / "age-specific-rates"
 AIRLINE_DATA_ROOT = COVID_19 / "airline-data"
+BRIEFS_DATA_ROOT = COVID_19 / "briefs-data"
+BRIEFS_OUTPUT_ROOT = COVID_19 / "briefs-outputs"
+COUNTIES_ROOT = COVID_19 / "counties"
 DATA_FIXES_ROOT = COVID_19 / "data-fixes"
 DATA_INTAKE_ROOT = COVID_19 / "data_intake"
+DEMOG_EM_INPUTS_ROOT = COVID_19 / "demog-em-inputs"
 DURATIONS_ROOT = COVID_19 / "durations"
 EXCESS_MORTALITY_ROOT = COVID_19 / "excess-mortality"
 GBD_ROOT = COVID_19 / "gbd"
-HISTORICAL_MODEL_ROOT = COVID_19 / "historical-model"
 MANDATES_ROOT = COVID_19 / "mandates"
 MASK_USE_OUTPUT_ROOT = COVID_19 / "mask-use-outputs"
 MOBILITY_COVARIATES_OUTPUT_ROOT = COVID_19 / "mobility-covariate"
@@ -42,12 +45,14 @@ MODEL_INPUTS_ROOT = COVID_19 / "model-inputs"
 MORTALITY_AGE_PATTERN_ROOT = COVID_19 / "mortality-age-pattern"
 MORTALITY_SCALARS_ROOT = COVID_19 / "mortality-scalars"
 NPI_REGRESSION_DATA_ROOT = COVID_19 / "npi-regression-data"
-PAST_INFECTIONS_ROOT = COVID_19 / "past-infections"
+NPI_REGRESSION_OUTPUT_ROOT = COVID_19 / "npi-regression-output"
 PNEUMONIA_OUTPUT_ROOT = COVID_19 / "pneumonia"
 POPULATION_DENSITY_OUTPUT_ROOT = COVID_19 / "population-density"
+QC_PLOTS_ROOT = COVID_19 / "qc-plots"
+RATES_COVARIATES_ROOT = COVID_19 / "rates-covariates"
 RESULTRON_ROOT = COVID_19 / "resultron"
-SEIR_COUNTERFACTUAL_INPUT_ROOT = COVID_19 / "seir-counterfactual-input"
 SEIR_COUNTERFACTUAL_ROOT = COVID_19 / "seir-counterfactual"
+SEIR_COUNTERFACTUAL_INPUT_ROOT = COVID_19 / "seir-counterfactual-input"
 SEIR_COVARIATE_PRIORS_ROOT = COVID_19 / "seir-covariate-priors"
 SEIR_COVARIATES_OUTPUT_ROOT = COVID_19 / "seir-covariates"
 SEIR_DIAGNOSTICS_OUTPUTS = COVID_19 / "seir-diagnostics"
@@ -69,7 +74,7 @@ VARIANT_OUTPUT_ROOT = COVID_19 / "variant-scaleup"
 VISIT_VOLUME_ROOT = COVID_19 / "visit-volume/"
 WANING_IMMUNITY_OUTPUT_ROOT = COVID_19 / "waning-immunity"
 WEBSCRAPER_ROOT = COVID_19 / "webscrape"
-
+ZIP_VACCINE_HESITANCY_ROOT = COVID_19 / "zip-vaccine-hesitancy"
 
 ######################################
 # Shared file and subdirectory names #
